#FirstWaveAnalysisFunctions.R
#Functions used to generate daily outcomes on patient-level
#Seperate file for functions to improve readability



#####################################################
#Identify lab measurement at each date
#Uses alternative definitions
#Baseline is -90 to +7
#Tricky how to handle assignment between baseline and 90 days
	#For now, only allow observations before day 1 to be assigned an upper range of day 1
	#For now, only allow observations after day 1 to be assigned a lower range of day 2
	#For now, take any labs BEFORE 180 days baseline
#Default as on 24JUL2014
#13AUG2014 - There is discussion regarding whether the window for VL measurements should be 180 or 90 days.  To make this work, we need a special case for the "6 month" time point.  There, we take any measurement before 180 days, but no measurements after (to avoid double-counting those assigned to the 1 year group).

lab.mat<-function(id,window,Cohort){
    
	anyvisit.lab<-anyvisit[anyvisit$table==id,]
	anyvisit.lab$obsnumber<-output.obsnumber(anyvisit.lab)
    
	lab.short<-anyvisit.lab[,c("site.patient","day","value","obsnumber")]
	
	lab.wide.temp<-reshape(lab.short,  idvar = "site.patient",
    timevar = "obsnumber", direction = "wide")
    
    
    
    lab.wide<-merge(lab.wide.temp,Cohort,by="site.patient",all.y=T)
    lab.wide<-lab.wide[,1:(dim(lab.wide)[2]-1)]
	lab.matrix<-matrix(NA,dim(lab.wide)[1],maxtime)
    
    
	for (j in 1:dim(lab.wide)[1]){
        
		counter<-2
		while (is.na(lab.wide[j,counter])==F & (counter+2) < dim(lab.wide)[2]) {
			range.lower<-lab.wide[j,counter]-window
			range.upper<-lab.wide[j,counter]+window
            	
			if ((counter -2) > 0 & (counter+2) < dim(lab.wide)[2]){
					range.lower.alt<-ceiling((lab.wide[j,counter]+lab.wide[j,counter-2])/2)
					range.upper.alt<-floor((lab.wide[j,counter]+lab.wide[j,counter+2])/2)
					range.lower<-ifelse(is.na(range.lower.alt)==F, 
								    ifelse(lab.wide[j,counter-2] < 0 & lab.wide[j,counter]>7, max(2,range.lower),
								  			max(range.lower.alt,range.lower)),
									   range.lower)
					range.upper<-ifelse(is.na(range.upper.alt)==F,
									ifelse(lab.wide[j,counter] <= 0 & lab.wide[j,counter+2]>0,
										min(1,range.upper),
										min(range.upper.alt,range.upper)),
									  range.upper)
							
                #range.lower<-max(ceiling((lab.wide[j,counter]+lab.wide[j,counter-2])/2),range.lower,na.rm=TRUE)
                #range.upper<-min(floor((lab.wide[j,counter]+lab.wide[j,counter+2])/2),range.upper,na.rm=TRUE)
			}
			
			if (lab.wide[j,counter] <= (-90) & lab.wide[j,counter] >= (-180) & range.upper<=0) 	range.upper<-1
			
			if (lab.wide[j,counter] < (window+10) & lab.wide[j,counter]>7) range.lower<-max(2,range.lower)
			#Want to explore a +/- 180 day window for lab measurements
			#Because they are also interested in measurements at 6 months, we need to make a special allowance
			#For 6 months, take all measurements before but none after
			if (window==180 & lab.wide[j,counter]>(365- window)) range.lower<-max(365-window+1,range.lower)
            if (window==180 & lab.wide[j,counter]<(365- window)) range.upper<-min(365-window,range.upper)
			if (lab.wide[j,counter] <=(0) & range.upper >2 ) range.upper<-(2)
            
			if (range.upper > maxtime) range.upper<-maxtime
			if (range.lower < 1) range.lower<-1
            
			if (range.lower < maxtime & range.upper > 0)  lab.matrix[j,range.lower:range.upper]<-lab.wide[j,counter+1]
			counter<-counter+2
		}
        
        
		if (lab.wide[j,1]%in%death.short$site.patient)
        lab.matrix[j,(death.short[death.short$site.patient==lab.wide[j,1],"day"]:maxtime)]<-"Dead"
        
        
        
    }
    
  if (id=="rna") {
    #Disaggregate between LTFU and Missing
    vl.matrix.LTFU<-matrix(NA,dim(lab.matrix)[1],dim(lab.matrix)[2])
    for (j in 1:dim(vl.matrix.LTFU)[1])
        {
            
            #01FEB2016 -- Add 'as.character' to deal with issues related to matching factor variables
        if (Cohort[j,"site.patient"]%in%censor.short$site.patient)
        vl.matrix.LTFU[j,(censor.short[as.character(censor.short$site.patient)==as.character(Cohort[j,"site.patient"]),"day"]:maxtime)]<-"LTFU"
        }
    
    lab.matrix.cat<- ifelse(is.na(lab.matrix),"Missing",
                    ifelse(lab.matrix=="LTFU","LTFU",
                    ifelse(lab.matrix=="Dead","Dead",
                    ifelse(abs(as.numeric(lab.matrix))<=400,  "000-400",
                    ifelse(abs(as.numeric(lab.matrix))<=1000, "401-1000",
                    "1001-Inf")))))

lab.matrix.cat<-ifelse(lab.matrix.cat=="Missing" & vl.matrix.LTFU=="LTFU" &is.na(vl.matrix.LTFU)==F,"LTFU", lab.matrix.cat)
#rm(vl.matrix.LTFU)

lab.matrix<-lab.matrix.cat
    }

#if (id=="cd4") {
#        lab.matrix.cat<- ifelse(is.na(lab.matrix),"Missing",
#                  ifelse(lab.matrix=="LTFU","LTFU",
#                 ifelse(lab.matrix=="Dead","Dead",
#                 ifelse(as.numeric(lab.matrix)<50, "000-049",
#                 ifelse(as.numeric(lab.matrix)<200, "050-199",
#                ifelse(as.numeric(lab.matrix)<350, "200-349",
#                "350-Inf")))))
#}


return(lab.matrix)

                                                   
}



lab.table<-function(id,lab.matrix.cat){
    #In very rare circumstances when working with simulated data, may have only 1 subject in data matrix (e.g., only 1 patient from mexico who is non-naive).  In these instances, the data is a vector unless you convince it to be a matrix (by transposing!) -- 06JUL2016
    if (is.vector(lab.matrix.cat)) lab.matrix.cat<-t(lab.matrix.cat)
    
    
    #14FEB2017 -- Current version of simulated data predates this analysis.  As such, some sites do not have simulated non-naive patients
    #Need to keep code from breaking by adding additional conditional statments to if() statments
    lab.table<-matrix(NA,dim(lab.matrix.cat)[2],6)
    
    if (id=="rna" & nrow(lab.matrix.cat)>0) {
        lab.table<-matrix(NA,dim(lab.matrix.cat)[2],6)
        lab.table[,6]<-apply(lab.matrix.cat=="Dead",2,mean,na.rm=T)
        lab.table[,4]<-apply(lab.matrix.cat=="Missing",2,mean,na.rm=T)
        lab.table[,5]<-apply(lab.matrix.cat=="LTFU",2,mean,na.rm=T)
        lab.table[,1]<-apply(lab.matrix.cat=="000-400",2,mean,na.rm=T)
        lab.table[,2]<-apply(lab.matrix.cat=="401-1000",2,mean,na.rm=T)
        lab.table[,3]<-apply(lab.matrix.cat=="1001-Inf",2,mean,na.rm=T)
    }
    
    if (id=="cd4"& nrow(lab.matrix.cat)>0){
        lab.table<-matrix(NA,dim(lab.matrix.cat)[2],6)
        lab.table[,6]<-apply(lab.matrix.cat=="Dead",2,mean,na.rm=T)
        lab.table[,5]<-apply(lab.matrix.cat=="000-049",2,mean,na.rm=T)
        lab.table[,4]<-apply(lab.matrix.cat=="050-199",2,mean,na.rm=T)
        lab.table[,3]<-apply(lab.matrix.cat=="200-349",2,mean,na.rm=T)
        lab.table[,2]<-apply(lab.matrix.cat=="350-Inf",2,mean,na.rm=T)
        lab.table[,1]<-apply(lab.matrix.cat=="Missing",2,mean,na.rm=T)
    }

    return(lab.table)
}



cd4.summarize<-function(cd4.matrix){


    cd4.matrix.numeric<-ifelse(cd4.matrix!="Missing" &  cd4.matrix!="Dead",as.numeric(cd4.matrix),NA)
    cd4.summary<-matrix(NA,dim(cd4.matrix)[2],3)
    #CD4 values at each time point - Median, 25%,75%
    cd4.summary[,1]<-round(apply(cd4.matrix.numeric,2,median,na.rm=T))
    cd4.summary[,2]<-round(apply(cd4.matrix.numeric,2, function(x) quantile(x,.25,na.rm=T)))
    cd4.summary[,3]<-round(apply(cd4.matrix.numeric,2, function(x) quantile(x,.75,na.rm=T)))
    colnames(cd4.summary)<-c("CD4 - Median","CD4 - 25 percentile","CD4 - 75 percentile")
    return(cd4.summary)
}

GenerateCD4catmatrix<-function(lab.matrix,Cohort){
    
    #Disaggregate between LTFU and Missing
    cd4.matrix.LTFU<-matrix(NA,dim(lab.matrix)[1],dim(lab.matrix)[2])
    for (j in 1:dim(cd4.matrix.LTFU)[1])
    {
        if (Cohort[j,"site.patient"]%in%censor.short$site.patient)
        cd4.matrix.LTFU[j,(censor.short[as.character(censor.short$site.patient)==as.character(Cohort[j,"site.patient"]),"day"]:maxtime)]<-"LTFU"
    }
    
    lab.matrix.cat<- ifelse(is.na(lab.matrix),"Missing",
    ifelse(lab.matrix=="LTFU","LTFU",
    ifelse(lab.matrix=="Dead","Dead",
    ifelse(abs(as.numeric(lab.matrix))<=400,  "000-400",
    ifelse(abs(as.numeric(lab.matrix))<=1000, "401-1000",
    "1001-Inf")))))
    
    lab.matrix.cat<-ifelse(lab.matrix.cat=="Missing" & cd4.matrix.LTFU=="LTFU" &is.na(cd4.matrix.LTFU)==F,"LTFU", lab.matrix.cat)
    #rm(cd4.matrix.LTFU)
    
    return(lab.matrix.cat)
}


#Fn to create percentage VL/CD4 missing
#Text at bottom of figures
LabPercentFn<-function(lab.matrix.cat,timepoints,timepoints.plot){
    
    lab.summary<-matrix(NA,dim(lab.matrix.cat)[2],3)
    lab.summary[,1]<-apply((lab.matrix.cat=="Missing"),2,sum)
    lab.summary[,2]<-dim(lab.matrix.cat)[1] - apply(lab.matrix.cat=="Dead" | 		lab.matrix.cat=="LTFU",2,sum,na.rm=T)
    lab.summary[,3]<-(lab.summary[,2]-lab.summary[,1])/lab.summary[,2]
    colnames(lab.summary)<-c("Number missing","Active","Percent with Obs")
    
    lab.freqbytime<-as.data.frame(cbind(lab.summary[timepoints,3],timepoints,timepoints.plot))
    lab.freqbytime[,1]<-round(lab.freqbytime[,1]*100,1)
    
	return(lab.freqbytime)
}


#used to create manuscript text
# % missing at 10 years
LabPercentbySite.timepoint<-function(lab.matrix.cat,timepoints,timepoints.plot,timeval,sitelist,lab,Cohort){
	
	percentwithlab<-NULL
	namevector<-NULL
	counter<-1
	for (i in sitelist){
		if (i!="overall") lab.matrix.cat.site<-lab.matrix.cat[Cohort$site==i,]
		if (i=="overall" &lab=="cd4") lab.matrix.cat.site<-lab.matrix.cat
        #For text, want to exclude Haiti from the percentage with missing VL
		if (i=="overall" &lab=="vl") lab.matrix.cat.site<-lab.matrix.cat[Cohort$site!="haiti",]
		labfreq.varioustimes<-LabPercentFn(lab.matrix.cat.site,timepoints,timepoints.plot)
		percentwithlab[counter]<-labfreq.varioustimes[labfreq.varioustimes$timepoints==timeval,1]
		counter<-counter+1
        
	}
    names(percentwithlab)<-sitelist
    return(percentwithlab)
}



areagraph<-function(labtable,lab,LabName,EveryDay="Yes",RemoveMissing="No",timepoints=NULL){
    options("OutDec"=".")
    
	if (RemoveMissing=="No") {
	    d1<-1:maxtime
	    d2<-as.data.frame(cbind(d1,labtable[,1],lab[1]))
	    d3<-as.data.frame(cbind(d1,labtable[,2],lab[2]))
	    d4<-as.data.frame(cbind(d1,labtable[,3],lab[3]))
	    d5<-as.data.frame(cbind(d1,labtable[,4],lab[4]))
	    d6<-as.data.frame(cbind(d1,labtable[,5],lab[5]))
	    d7<-as.data.frame(cbind(d1,labtable[,6],lab[6]))
		
		if (EveryDay=="No") {
			d2<-d2[timepoints,]
			d3<-d3[timepoints,]
			d4<-d4[timepoints,]
			d5<-d5[timepoints,]
			d6<-d6[timepoints,]
			d7<-d7[timepoints,]
			}
		
	    colnames(d2)<-colnames(d3)<-colnames(d4)<-colnames(d5)<-colnames(d6)<-colnames(d7)<-c("x","y","Val")
    
	    area<-rbind(d2,d3,d4,d5,d6,d7)
		
		}	
		
	if (RemoveMissing=="Yes") {
		#We may want to remove those who are active, but missing a measurement
		#Assume they are missing completely at random.  Re-weight the three VL measurement categories 
		#(no changes to the LTFU/Dead percentages).  The key variable here is -replacemissing-.
    
		replacemissing<-labtable[,4]/(labtable[,1]+labtable[,2]+labtable[,3])
    	d1<-1:maxtime
    	d2<-as.data.frame(cbind(d1,labtable[,1]*(1+replacemissing),lab[1]))
    	d3<-as.data.frame(cbind(d1,labtable[,2]*(1+replacemissing),lab[2]))
    	d4<-as.data.frame(cbind(d1,labtable[,3]*(1+replacemissing),lab[3]))
    	d5<-as.data.frame(cbind(d1,labtable[,5],lab[4]))
    	d6<-as.data.frame(cbind(d1,labtable[,6],lab[5]))
		
	if (EveryDay=="No") {
		d2<-d2[timepoints,]
		d3<-d3[timepoints,]
		d4<-d4[timepoints,]
		d5<-d5[timepoints,]
		d6<-d6[timepoints,]
		}
		
    colnames(d2)<-colnames(d3)<-colnames(d4)<-colnames(d5)<-colnames(d6)<-c("x","y","Val")
    
    area<-rbind(d2,d3,d4,d5,d6)
    
	}
    
    	if (RemoveMissing=="Drug") {
		#Sloppy coding here, but want to add areagraph for drug dispensation so I am brute forcing it into this function originally designed for VL area graphs
    
		d1<-1:maxtime
	    d2<-as.data.frame(cbind(d1,labtable[,1],lab[1]))
	    d3<-as.data.frame(cbind(d1,labtable[,2],lab[2]))
	    d4<-as.data.frame(cbind(d1,labtable[,3],lab[3]))
	    d5<-as.data.frame(cbind(d1,labtable[,4],lab[4]))
	    d6<-as.data.frame(cbind(d1,labtable[,5],lab[5]))
	    d7<-as.data.frame(cbind(d1,labtable[,6],lab[6]))
        d8<-as.data.frame(cbind(d1,labtable[,7],lab[7]))
		
		if (EveryDay=="No") {
			d2<-d2[timepoints,]
			d3<-d3[timepoints,]
			d4<-d4[timepoints,]
			d5<-d5[timepoints,]
			d6<-d6[timepoints,]
			d7<-d7[timepoints,]
            d8<-d8[timepoints,]
			}
		
	    colnames(d2)<-colnames(d3)<-colnames(d4)<-colnames(d5)<-colnames(d6)<-colnames(d7)<-colnames(d8)<-c("x","y","Val")
    
	    area<-rbind(d2,d3,d4,d5,d6,d7,d8)
		
		}
    
    
    area$x<-as.numeric(as.character(area$x))/365.25
    area$y<-as.numeric(as.character(area$y))
    
    area<-area[area$x<=10,]
    
    #14FEB2017 -- Need to reverse the factor ordering so that plots stack similarly to the paper
    area$Val<-factor(area$Val, levels = rev(levels(area$Val)))
    lab<-rev(lab)
    
    #Need to modify this assignment of colors as well
    if(RemoveMissing=="No") fill.col<- c("green", "orange", "red","white","grey","black")
    if(RemoveMissing=="Yes") fill.col<- c("green", "orange", "red","grey90","black")
    if(RemoveMissing=="Drug") fill.col<- c("dark green","green", "orange", "red","grey90","grey","black")

    fill.col<-rev(fill.col)

    p1<- ggplot(area, aes(x = x, y = y)) +  geom_area(aes(fill = Val), position = 'stack')  + scale_y_continuous(expand = c(0,0))  + theme_bw()
	p2<- p1 + xlab("Year") + ylab("Proportion of patients") + scale_x_continuous(expand = c(0,0),limits = c(0, 10))
	p3<-p2+ scale_fill_manual(values=c(fill.col), name=LabName,labels=lab)

    #options("OutDec"="\u00B7")
    
    return(p3)
}



PlotFn<-function(vl.matrix.cat,cd4.matrix,tiff.file="No",EveryDay="Yes",RemoveMissing="No",window=90,legendinclude="FALSE"){
    p.vl<-p.vl.median<-p.vl.Q1<-p.vl.Q3<-NULL
    
    
    vl.table<-lab.table("rna",vl.matrix.cat)
    cd4.summary<-cd4.summarize(cd4.matrix)
    
    
    
    
    #Prep work to get ready for plotting of VL cascade AND median CD4s
    if (window==180) {
        timepoints<-c(1,182,floor(seq(1:10)*365.25))
        timepoints.plot<-c(30,150,floor(seq(1:10)*365.25)-50)
    }
    
    if (window==90) {
        timepoints<-c(1,floor(seq(1:20)*182.625))
        timepoints.plot<-c(30,floor(seq(1:20)*182.625)-50)
        
        #28SEP2014
        #Want to print CD4 measurements every 180 days, but numerically label them every 365
        
        timepoints.CD4label<-c(1,floor(seq(1:10)*365.25))
        #timepoints.plot.CD4label<-c(30,300,floor(seq(1:9)*365.25+365.25)-160)
        timepoints.plot.CD4label<-c(30,seq(1:10)*350)
        
    }
    
    
    
    if (EveryDay=="Yes") {
        area2<-as.data.frame(cbind(cd4.summary[1:floor(365.25*10),1:3],1:3652/365.25))
        colnames(area2)<-c("Median","Q1","Q3","x")
    }
    
    if (EveryDay=="No") {
        area2<-as.data.frame(cbind(cd4.summary[timepoints,1:3],timepoints/365.25))
        colnames(area2)<-c("Median","Q1","Q3","x")
    }
    
    area3<-as.data.frame(cbind(cd4.summary[timepoints.CD4label,1:3],timepoints.CD4label,timepoints.plot.CD4label))
    colnames(area3)<-c("Median","Q1","Q3","timepoints","timepoints.plot")
    
    if (RemoveMissing=="Yes") label.vl<-c("0-400","401-1000","> 1000","LTFU","Dead")
    if (RemoveMissing=="No")  label.vl<-c("0-400","401-1000","> 1000","No measurement","LTFU","Dead")
    
    if (tiff.file=="No"){
        numsize<-4  #Was actually 4 in PlotFn() in previous versions.  May want to change back to 4 for pdf version?
        pointsize<-2
        textsize<-NULL
        axissize<-NULL
        
    }
    
    if (tiff.file=="Yes"){
        numsize<-1.5
        pointsize<-1.25
        textsize<-4
        axissize<-0.1
    }
    
    
    
    p.vl<-areagraph(vl.table,label.vl,"Viral load copies/mL",EveryDay=EveryDay,RemoveMissing=RemoveMissing, timepoints=timepoints)  + theme(legend.position = "none") +theme(text = element_text(size=textsize),axis.ticks  = element_line(size=axissize))
    p.vl.Q1<-p.vl+ geom_line(data=area2, aes(x = x, y = Q1/2500), color="grey90") + geom_point(data=area3, aes(x = timepoints/365.25, y = Q1/2500), color="grey90",size=pointsize) +geom_text(data=area3,aes(label=Q1,x = timepoints.plot/365.25, y = Q1/2500),hjust=0, vjust=-1,size=numsize)
    p.vl.Q3<-p.vl.Q1+ geom_line(data=area2, aes(x = x, y = Q3/2500), color="grey90") + geom_point(data=area3, aes(x = timepoints/365.25, y = Q3/2500), color="grey90",size=pointsize) +geom_text(data=area3,aes(label=Q3,x = timepoints.plot/365.25, y = Q3/2500),hjust=0, vjust=-1,size=numsize)
    p.vl.median<-p.vl.Q3+ geom_line(data=area2, aes(x = x, y = Median/2500), color="black") + geom_point(data=area3, aes(x = timepoints/365.25, y = Median/2500), color="black",size=pointsize) +geom_text(data=area3,aes(label=Median,x = timepoints.plot/365.25, y = Median/2500),hjust=0, vjust=-1,size=numsize)
    
    p.final<-p.vl.median
    if (legendinclude=="TRUE") p.final <- p.vl.median + theme(legend.position = "top")
    
    p.final
    
}


#http://stackoverflow.com/questions/15826831/r-adding-a-datatable-to-a-ggplot-graph-using-viewports-scaling-the-grob
#Combine two plots (e.g., regular plot and data table)


PlotDataTable<-function(vl.matrix.cat,cd4.matrix,cd4.matrix.cat,tiff.file="No",EveryDay="No",RemoveMissing="Yes",window=90,legendinclude="FALSE"){
    if (tiff.file=="No"){
        numsize<-4.5  #Was actually 4 in PlotFn() in previous versions.  May want to change back to 4 for pdf version?
        textsize<-NULL
        marginsleft<-0.5
        marginright<-0
        
    }
    
    if (tiff.file=="Yes"){
        #Plots look differently when saved as pdf v tiff
        #Notably, the size of the the numbers (numsize), axes text (textsize), points (pointsize),and spacing of margins (marginsleft/marginright) differ
        #The following code should allow plots to look reasonable for each type...just specify the variable "tiff.file" in the function statement
        numsize<-1.5
        textsize<-4
        marginsleft<-0.5
        marginright<--0.5
        
    }
    options("OutDec"=".")
    
    require(ggplot2)
    require(grid)
    require(reshape2)
    
    
    p1<-PlotFn(vl.matrix.cat,cd4.matrix,tiff.file=tiff.file,EveryDay=EveryDay,RemoveMissing=RemoveMissing,window=window,legendinclude=legendinclude)
    
    
    #18AUG2014 - regardless of windows, only print VL percentages every year
    if (window==90 | window==180) {
        timepoints<-c(1,floor(seq(1:10)*365.25))
        timepoints.plot<-c(30,floor(seq(1:10)*365.25)-50)
    }
    
    
    vl.freqbytime<-LabPercentFn(vl.matrix.cat,timepoints,timepoints.plot)
    cd4.freqbytime<-LabPercentFn(cd4.matrix.cat,timepoints,timepoints.plot)
    
    
    none <- element_blank()
    data_table <- ggplot(vl.freqbytime, aes(x = timepoints, y = 1,
    label = format(V1, nsmall = 1), colour = 1)) +
    geom_text(size = numsize) +
    scale_y_discrete(labels = "VL")+ theme_bw()  +
    theme(panel.grid.major = none, legend.position = "none",
    panel.border = none, axis.text.x = none,
    axis.ticks = none) + theme(plot.margin = unit(c(-0.5, marginright, 0, marginsleft), "lines")) + xlab(NULL) + ylab(NULL) +theme(text = element_text(size=textsize))
    
    
    none <- element_blank()
    data_table2 <- ggplot(cd4.freqbytime, aes(x = timepoints, y = 1,
    label = format(V1, nsmall = 1), colour = 1)) +
    geom_text(size = numsize) +
    scale_y_discrete(labels = "CD4")+ theme_bw()  +
    theme(panel.grid.major = none, legend.position = "none",
    panel.border = none, axis.text.x = none,
    axis.ticks = none) + theme(plot.margin = unit(c(-0.5, marginright, 0, 0), "lines")) + xlab(NULL) + ylab(NULL) +theme(text = element_text(size=textsize))
    
    #Ineffecient (but quick!) strategy to add a line of text to plot
    none <- element_blank()
    data_table3 <- ggplot(vl.freqbytime, aes(x = timepoints, y = 1,
    label = format("", nsmall = 1), colour = 1)) +
    geom_text(size = numsize) +
    scale_y_discrete(labels = "% measured")+ theme_bw()  +
    theme(panel.grid.major = none, legend.position = "none",
    panel.border = none, axis.text.x = none,
    axis.ticks = none) + theme(plot.margin = unit(c(-0.5, marginright, 0, 0), "lines")) + xlab(NULL) + ylab(NULL) +theme(text = element_text(size=textsize))
    
    
    
    if (tiff.file=="Yes") {
        Layout <- grid.layout(nrow = 4, ncol = 1, heights = unit(c(2,
        0.06,0.075,0.075), c("null", "null")))
    }
    
    if (tiff.file=="No") {
        Layout <- grid.layout(nrow = 4, ncol = 1, heights = unit(c(2,
        0.1,0.05,0.05), c("null", "null")))
    }
    #grid.show.layout(Layout)
    vplayout <- function(...) {
        grid.newpage()
        pushViewport(viewport(layout = Layout))
    }
    
    subplot <- function(x, y) viewport(layout.pos.row = x,
    layout.pos.col = y)
    
    mmplot <- function(a, b,c,d) {
        vplayout()
        print(a, vp = subplot(1, 1))
        print(b, vp = subplot(2, 1))
        print(c, vp = subplot(3, 1))
        print(d, vp = subplot(4, 1))
    }
    
    mmplot(p1, data_table3,data_table,data_table2)
}



PlotDataTableSite<-function(sitelab,vl.matrix.cat,cd4.matrix,cd4.matrix.cat,tiff.file=tiff.file,EveryDay="Yes",RemoveMissing="No",window=90,legendinclude="FALSE",Cohort){
    
    vl.matrix.cat<-vl.matrix.cat[Cohort$site==sitelab,]
    cd4.matrix<-cd4.matrix[Cohort$site==sitelab,]
    cd4.matrix.cat<-cd4.matrix.cat[Cohort$site==sitelab,]
    PlotDataTable(vl.matrix.cat,cd4.matrix,cd4.matrix.cat,tiff.file=tiff.file, EveryDay=EveryDay,RemoveMissing=RemoveMissing,window=window,legendinclude=legendinclude)
}







output.obsnumber<-function(dat){
	#12OCT2014
	#Speed up this function by making ID comparison outside loop
	obsnumber<-NULL
	counter<-0
	PreviousID<-c("NA",as.character(dat$site.patient[1:(dim(dat)[1]-1)]))
	Sameobs<-as.numeric(dat$site.patient==PreviousID)
	for (i in 1:dim(dat)[1]){
		counter<-Sameobs[i]*counter+1
		obsnumber[i]<-counter
        
	}
    return(obsnumber)
}








#Function to calculate p-value for differences between two groups
#Used mostly in Supplemental analyses
#Patients with VL v patients without
#ART-naive versus not ART naive



CategoricalCompare.pval<-function(dat,var){
    #Format for HIV Lancet
    #options("OutDec"="\u00B7")
    
    categorical.var<-c("male","ARVclass","modetransmission","aids.initiation","aids.initiation.all","Initiation.Year.cat","BaselineVL.Undetectable","recart_y","nadirCD4.missing","baselineCD4.missing")
    rownumb<-0
    
    Table.cat.pvalue<-as.data.frame(matrix(NA,length(categorical.var)*length(sitelist),3))
    
    for (k in sitelist) {
        
        if (k=="overall") dat.var<-dat
        else dat.var<-dat[dat$site==k,]
        for (i in categorical.var){
            rownumb<-rownumb+1
            Table.cat.pvalue[rownumb,1]<-k
            Table.cat.pvalue[rownumb,2]<-i
            temp.p<-NULL
            temp.p<-ifelse(length(levels(as.factor(as.character((dat.var[,i])))))>1 & length(levels(as.factor(as.character(dat.var[,var]))))>1
            & sum(table(dat.var[,i],dat.var[,var])!=0)>2,
            round(chisq.test(dat.var[,i],dat.var[,var])$p.value,3),
            NA)
            
            Table.cat.pvalue[rownumb,3]<-ifelse(temp.p<0.001,paste("<",0.001,sep=""),format(temp.p,nsmall=3))
            


        }
    }
    
    colnames(Table.cat.pvalue)<-c("site","var","pvalue")
    
    Table.cat.pvalue.argentina<-subset(Table.cat.pvalue,Table.cat.pvalue[,1]=="argentina")
    Table.cat.pvalue.brazil<-subset(Table.cat.pvalue,Table.cat.pvalue[,1]=="brazil")
    Table.cat.pvalue.chile<-subset(Table.cat.pvalue,Table.cat.pvalue[,1]=="chile")
    Table.cat.pvalue.haiti<-subset(Table.cat.pvalue,Table.cat.pvalue[,1]=="haiti")
    Table.cat.pvalue.honduras<-subset(Table.cat.pvalue,Table.cat.pvalue[,1]=="honduras")
    Table.cat.pvalue.mexico<-subset(Table.cat.pvalue,Table.cat.pvalue[,1]=="mexico")
    Table.cat.pvalue.overall<-subset(Table.cat.pvalue,Table.cat.pvalue[,1]=="overall")
    
    Table1cat.pvalue.merge2<-merge(Table.cat.pvalue.argentina,Table.cat.pvalue.brazil,by=c("var"),all=T)
    colnames(Table1cat.pvalue.merge2)<-c("var","site.1","pvalue.1",
    "site.2","pvalue.2"
    )
    Table1cat.pvalue.merge3<-merge(Table1cat.pvalue.merge2,Table.cat.pvalue.chile,by=c("var"),all=T)
    colnames(Table1cat.pvalue.merge3)<-c(colnames(Table1cat.pvalue.merge2),
    "site.3","pvalue.3"
    )
    Table1cat.pvalue.merge4<-merge(Table1cat.pvalue.merge3,Table.cat.pvalue.haiti,by=c("var"),all=T)
    colnames(Table1cat.pvalue.merge4)<-c(colnames(Table1cat.pvalue.merge3),
    "site.4","pvalue.4"
    )
    Table1cat.pvalue.merge5<-merge(Table1cat.pvalue.merge4,Table.cat.pvalue.honduras,by=c("var"),all=T)
    colnames(Table1cat.pvalue.merge5)<-c(colnames(Table1cat.pvalue.merge4),
    "site.5","pvalue.5"
    )
    Table1cat.pvalue.merge6<-merge(Table1cat.pvalue.merge5,Table.cat.pvalue.mexico,by=c("var"),all=T)
    colnames(Table1cat.pvalue.merge6)<-c(colnames(Table1cat.pvalue.merge5),
    "site.6","pvalue.6"
    )
    Table1cat.pvalue.merge7<-merge(Table1cat.pvalue.merge6,Table.cat.pvalue.overall,by=c("var"),all=T)
    colnames(Table1cat.pvalue.merge7)<-c(colnames(Table1cat.pvalue.merge6),
    "site.7","pvalue.7"
    )
    Table1cat.pvalue<-Table1cat.pvalue.merge7
    
    options("OutDec"=".")
    
    return(Table1cat.pvalue)
}



ContinuousCompare.pval<-function(dat,var){
   continuous.var<-c("age","BaselineCD4","nadirCD4","BaselinelogVL","Initiation.Year")
    rownumb<-0
    
    Table.cont.pvalue<-as.data.frame(matrix(NA,length(continuous.var)*length(sitelist),3))
    
    for (k in sitelist) {
        if (k=="overall") dat.var<-dat
        else dat.var<-dat[dat$site==k,]
        for (i in continuous.var){
            rownumb<-rownumb+1
            Table.cont.pvalue[rownumb,1]<-k
            Table.cont.pvalue[rownumb,2]<-i
            temp.p<-NULL
            temp.p<-with(dat.var,
            ifelse(sum(is.na(subset(dat.var[,i],dat.var[,var]==1))==F)>0 & sum(is.na(subset(dat.var[,i],dat.var[,var]==0))==F)>0,
            round(wilcox.test(dat.var[,i]~dat.var[,var])$p.value,3),
            NA))
            
            Table.cont.pvalue[rownumb,3]<-ifelse(temp.p<0.001,paste("<",0.001,sep=""),format(temp.p,nsmall=3))
        }
    }
    
    colnames(Table.cont.pvalue)<-c("site","var","pvalue")
    
    Table.cont.pvalue.argentina<-subset(Table.cont.pvalue,Table.cont.pvalue[,1]=="argentina")
    Table.cont.pvalue.brazil<-subset(Table.cont.pvalue,Table.cont.pvalue[,1]=="brazil")
    Table.cont.pvalue.chile<-subset(Table.cont.pvalue,Table.cont.pvalue[,1]=="chile")
    Table.cont.pvalue.haiti<-subset(Table.cont.pvalue,Table.cont.pvalue[,1]=="haiti")
    Table.cont.pvalue.honduras<-subset(Table.cont.pvalue,Table.cont.pvalue[,1]=="honduras")
    Table.cont.pvalue.mexico<-subset(Table.cont.pvalue,Table.cont.pvalue[,1]=="mexico")
    Table.cont.pvalue.overall<-subset(Table.cont.pvalue,Table.cont.pvalue[,1]=="overall")
    
    Table1cont.pvalue.merge2<-merge(Table.cont.pvalue.argentina,Table.cont.pvalue.brazil,by=c("var"),all=T)
    colnames(Table1cont.pvalue.merge2)<-c("var","site.1","pvalue.1",
    "site.2","pvalue.2"
    )
    Table1cont.pvalue.merge3<-merge(Table1cont.pvalue.merge2,Table.cont.pvalue.chile,by=c("var"),all=T)
    colnames(Table1cont.pvalue.merge3)<-c(colnames(Table1cont.pvalue.merge2),
    "site.3","pvalue.3"
    )
    Table1cont.pvalue.merge4<-merge(Table1cont.pvalue.merge3,Table.cont.pvalue.haiti,by=c("var"),all=T)
    colnames(Table1cont.pvalue.merge4)<-c(colnames(Table1cont.pvalue.merge3),
    "site.4","pvalue.4"
    )
    Table1cont.pvalue.merge5<-merge(Table1cont.pvalue.merge4,Table.cont.pvalue.honduras,by=c("var"),all=T)
    colnames(Table1cont.pvalue.merge5)<-c(colnames(Table1cont.pvalue.merge4),
    "site.5","pvalue.5"
    )
    Table1cont.pvalue.merge6<-merge(Table1cont.pvalue.merge5,Table.cont.pvalue.mexico,by=c("var"),all=T)
    colnames(Table1cont.pvalue.merge6)<-c(colnames(Table1cont.pvalue.merge5),
    "site.6","pvalue.6"
    )
    Table1cont.pvalue.merge7<-merge(Table1cont.pvalue.merge6,Table.cont.pvalue.overall,by=c("var"),all=T)
    colnames(Table1cont.pvalue.merge7)<-c(colnames(Table1cont.pvalue.merge6),
    "site.7","pvalue.7"
    )
    Table1cont.pvalue<-Table1cont.pvalue.merge7
    
    options("OutDec"=".")
    return(Table1cont.pvalue)
}
