
#Perform Cascade Analysis
#Last Modified: 08DEC2015
#Giganti

#This file does most of the heavy lifting for this analysis.  It evaluates patient status for labs and outcomes at all time points throughout 10 years.
#Note that in the analysis stage we looked at many contingencies (90 v 180 day windows, include missing lab patients in figures or extrapolate their lab values based upon observed values, use everyday intervals or 6 month intervals, etc.).  The functions were designed to look at these various contingencies, but sacrificed code readability!

#The following should be run first.

#FirstWave Data Prep (CCASAnet).R generates an analysis dataset
#FirstWaveAnalysisFunctions.R contains functions that will be used in this code


#19SEP2014   We have decided to use the 6 month intervals with 90 day windows.  We will remove the missing patients from the figure and report percentage of observed VLs.  We have deprecated everyday intervals, 180 day windows, and the inclusion of missing labs as a category in the figure.

#Important note:  LTFU for the drug cascade is different from LTFU for the VL cascade
#In VL cascade, they were LTFU if no measurements greater than 180 days after last VL
#Here, they are only classified as LTFU if they have a formal LTFU entry in the follow table

#08DEC2015 - We now want to generate figures for both non-naive and naive patients.


#01FEB2016 - Figures that do not include IPW weights are deprecated.  Code generating those figures have been removed.

##############################################################################################
##############################################################################################
##############################################################################################
##############################################################################################


#If we want to rerun the entire analysis, change update from 0 to 1
#Current run time < 2 hours (Made noteworthy changes to drug matrix to speed things up in Oct 2014)
#Most recent update date: 29DEC2014 (update Haiti/Honduras data following queries)

update<-1


    FreezeDate<-as.Date('2004-01-01')
    #All functions located in one file
    #source('~/Documents/CCASAnet/FirstWave/FirstWaveAnalysisFunctions.R', chdir = TRUE)
    #source('~/Documents/CCASAnet/FirstWave/FirstWave Data Prep (CCASAnet).R', chdir = FALSE)
    #setwd("~/Documents/CCASAnet/FirstWave")
    
    
    setwd("~/Dropbox/datasim/first-wave")
    source('FirstWaveAnalysisFunctions.R', chdir = TRUE)
    source('FirstWave Data Prep (CCASAnet).R', chdir = FALSE)
    
    #Keep patients who are non-naive
    Pre2004Cohort<-CCASAnet_Analysis[,c("site.patient","site","FirstHAARTdate")]

    #Exclude patients less than 18 and non-naive
    #Pre2004Cohort<-Pre2004Cohort_temp[Pre2004Cohort_temp$naive==1,c("site.patient","site","FirstHAARTdate")]

    ####################################################################
    #We now want to map patient outcomes at every time point for every patient in cohort
    #Restrict each table to only eligible patients
    ####################################################################
    #With 10 year window, do not need obs greater than 4000 days
    maxtime<-4000

    visit.short<-cbind(visit[,c("site.patient","visit_dt")],NA,"visit")
    cd4.short<-cbind(lab_cd4[,c("site.patient","cd4_dt","cd4_v")],"cd4")
    vl.short<-cbind(lab_rna[,c("site.patient","rna_dt","rna_v")],"rna")
    drug.short<-cbind(art[,c("site.patient","startdate","art_id")],"art")

    colnames(visit.short)<-colnames(cd4.short)<-colnames(vl.short)<-colnames(drug.short)<-c("site.patient","date","value","table")

    all.short<-rbind(visit.short,
	  cd4.short,
	  vl.short,
      drug.short
	  )
	  	  
	 
     anyvisit<-merge(Pre2004Cohort,all.short,by="site.patient")
     anyvisit<-anyvisit[is.na(anyvisit$date)==F,]
     anyvisit$day<-with(anyvisit,as.numeric(date-FirstHAARTdate))
     anyvisit<-with(anyvisit, anyvisit[order(site.patient,date),])


    death.short<-merge(Pre2004Cohort,follow[follow$death_y==1,c("site.patient","death_dt")],by="site.patient")
    death.short$day<-with(death.short,as.numeric(as.Date(death_dt,origin="1970-01-01")-FirstHAARTdate))
    death.short<-death.short[death.short$day<maxtime & is.na(death.short$day)==F,]

    output.obsnumber<-function(dat){
	#12OCT2014 
	#Speed up this function by making ID comparison outside loop
	obsnumber<-NULL
	counter<-0
	PreviousID<-c("NA",as.character(dat$site.patient[1:(dim(dat)[1]-1)]))
	Sameobs<-as.numeric(dat$site.patient==PreviousID)
	for (i in 1:dim(dat)[1]){
		counter<-Sameobs[i]*counter+1
		obsnumber[i]<-counter	
        }
    return(obsnumber)
    }

    censor.short<-merge(follow.short[follow.short$death_y!=1,c("site.patient","censor_dt")],Pre2004Cohort,by=c("site.patient"))
    censor.short$day<-with(censor.short,as.numeric(as.Date(censor_dt,origin="1970-01-01")-FirstHAARTdate))
    censor.short<-censor.short[censor.short$day<maxtime & is.na(censor.short$day)==F,]

    #20OCT2014 - BS & MG discussed how to handle LTFU near 10 year interval.  Originally planned to allow anyone with visit within 90 days of 10 years to be active.  Giganti, after consideration, decided to add 90 day grace period from end of last visit before classified as LTFU. WTD?
    censor.short$day<-censor.short$day+90
    censor.short<-censor.short[censor.short$day<maxtime & is.na(censor.short$day)==F,]


    #Create a category for unknown aids initiation status
    CCASAnet_Analysis$aids.initiation.plus<-ifelse(is.na(CCASAnet_Analysis$aids.initiation),"Unknown",CCASAnet_Analysis$aids.initiation)
    #only two with unknown ART-naive status.  Move them into no group just so we can get reliable weights

##############################################################################################
if (update==1){

    vl.matrix.cat.90<-lab.mat("rna",window=90,Cohort=Pre2004Cohort)
    cd4.matrix.90<-lab.mat("cd4",window=90,Cohort=Pre2004Cohort)
    #save(vl.matrix.cat.90,file="/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_VLMatrix.Rda")
    #save(cd4.matrix.90,file="/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_CD4Matrix.Rda")
    save(vl.matrix.cat.90,file="FirstWave_VLMatrix.Rda")
    save(cd4.matrix.90,file="FirstWave_CD4Matrix.Rda")

    #Due to memory issues need to temporarily remove the VL matrix and re-add when finished)
    rm(vl.matrix.cat.90)


}
##############################################################################################
##############################################################################################




#Import saved datasets
#load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_VLMatrix.Rda")
#load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_CD4Matrix.Rda")
#source('~/Documents/CCASAnet/FirstWave/FirstWaveAnalysisFunctions.R', chdir = TRUE)
load("FirstWave_VLMatrix.Rda")
load("FirstWave_CD4Matrix.Rda")

#Need to create a few new folders (2016-04-02)
if (dir.exists("Rdatasets")==FALSE)    dir.create("Rdatasets")

source('FirstWaveAnalysisFunctions.R', chdir = TRUE)
#Provide categories for CD4 counts - needed to count percent missing
cd4.matrix.cat.90<-GenerateCD4catmatrix(cd4.matrix.90,Cohort=Pre2004Cohort)


##############################################################################################
####Revise Person-day VL dataset
####Use IPW to replace missing values
####Want to create datasets for entire dataset and naive
####Do seperately for each site and them combine
####This helps us sync up with the original dataset and generate site-specific figures
####For logistic model to predict complete data, want to use all available data -- however, certain sites missing certain variables
####Need to account for these conditions.  I did it quick/dirty with for loops, but not most efficient
##############################################################################################

#No VLs for Haiti...remove them from IPW
VL.IPW.bysite<-function(s,naiveonly="no"){
    set.seed(455)
inclusion<-CCASAnet_Analysis$site==s
if (naiveonly=="yes") inclusion<-CCASAnet_Analysis$site==s & CCASAnet_Analysis$naive==1
CCASAnet_Analysis_site<-CCASAnet_Analysis[inclusion,]
CCASAnet_Analysis_site$modetransmission<-as.character(CCASAnet_Analysis_site$modetransmission)
CCASAnet_Analysis_site$ARVclass<-as.character(CCASAnet_Analysis_site$ARVclass)

vl.matrix.cat.90.site<-vl.matrix.cat.90[inclusion,]

vl.matrix.cat.90.IPW<-matrix(NA,nrow(vl.matrix.cat.90.site),ncol(vl.matrix.cat.90.site))

for (pp in 1:ncol(vl.matrix.cat.90)){
complete<-ifelse(vl.matrix.cat.90.site[,pp]=="Missing",0,
		  ifelse(vl.matrix.cat.90.site[,pp] %in% c("Dead","LTFU"),NA,1))

#Mexico has very few non-naive patients.  Original code included 'naive' as a covariate for all sites.   I am amending it here to not be included for Mexico (06JUL2016)
if (naiveonly=="no" & s!="mexico") {output<-glm(complete~age+male+aids.initiation.plus+ARVclass+modetransmission+factor(naive),
data=CCASAnet_Analysis_site,family="binomial")
}
if (naiveonly=="yes" | s=="mexico"){
	output<-glm(complete~age+male+aids.initiation.plus+ARVclass+modetransmission,data=CCASAnet_Analysis_site,family="binomial")
}
p<-as.numeric(1/(1+exp(-predict(output,newdata=CCASAnet_Analysis_site[is.na(complete)==F,]))))

weight.cat1<-sum(as.numeric(vl.matrix.cat.90.site[is.na(complete)==F,pp]=="000-400")*1/(p))
weight.cat2<-sum(as.numeric(vl.matrix.cat.90.site[is.na(complete)==F,pp]=="401-1000")*1/(p))
weight.cat3<-sum(as.numeric(vl.matrix.cat.90.site[is.na(complete)==F,pp]=="1001-Inf")*1/(p))
weight.tot<-weight.cat1+weight.cat2+weight.cat3

N.cat1<-round(weight.cat1/weight.tot*sum(is.na(complete)==F))
N.cat2<-round(weight.cat2/weight.tot*sum(is.na(complete)==F))
N.cat3<-sum(is.na(complete)==F)-N.cat1-N.cat2
vl.matrix.cat.90.IPW[,pp]<-c(rep("000-400",N.cat1),rep("401-1000",N.cat2),rep("1001-Inf",N.cat3),rep("Dead",sum(vl.matrix.cat.90.site[,pp]=="Dead")),rep("LTFU",sum(vl.matrix.cat.90.site[,pp]=="LTFU")))
#print(pp)
}
return(vl.matrix.cat.90.IPW)

}

if (update==1){

vl.matrix.cat.90.IPW.argentina<-VL.IPW.bysite("argentina")
vl.matrix.cat.90.IPW.brazil<-VL.IPW.bysite("brazil")
vl.matrix.cat.90.IPW.chile<-VL.IPW.bysite("chile")
vl.matrix.cat.90.IPW.honduras<-VL.IPW.bysite("honduras")
vl.matrix.cat.90.IPW.mexico<-VL.IPW.bysite("mexico")
vl.matrix.cat.90.IPW<-rbind(vl.matrix.cat.90.IPW.argentina,vl.matrix.cat.90.IPW.brazil,vl.matrix.cat.90.IPW.chile,vl.matrix.cat.90[CCASAnet_Analysis$site=="haiti",],vl.matrix.cat.90.IPW.honduras,vl.matrix.cat.90.IPW.mexico)

#save(vl.matrix.cat.90.IPW,file="/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_VLMatrix_IPW.Rda")
save(vl.matrix.cat.90.IPW,file="FirstWave_VLMatrix_IPW.Rda")




vl.matrix.cat.naive.IPW.argentina<-VL.IPW.bysite("argentina",naiveonly="yes")
vl.matrix.cat.naive.IPW.brazil<-VL.IPW.bysite("brazil",naiveonly="yes")
vl.matrix.cat.naive.IPW.chile<-VL.IPW.bysite("chile",naiveonly="yes")
vl.matrix.cat.naive.IPW.honduras<-VL.IPW.bysite("honduras",naiveonly="yes")
vl.matrix.cat.naive.IPW.mexico<-VL.IPW.bysite("mexico",naiveonly="yes")
vl.matrix.cat.naive.IPW<-rbind(vl.matrix.cat.naive.IPW.argentina,vl.matrix.cat.naive.IPW.brazil,vl.matrix.cat.naive.IPW.chile,vl.matrix.cat.90[CCASAnet_Analysis$site=="haiti" & CCASAnet_Analysis$naive==1,],vl.matrix.cat.naive.IPW.honduras,vl.matrix.cat.naive.IPW.mexico)
#save(vl.matrix.cat.naive.IPW,file="/Users/giganti/Documents/CCASAnet/FirstWave/Rdatasets/FirstWave_VLMatrix_naive_IPW.Rda")
save(vl.matrix.cat.naive.IPW,file="Rdatasets/FirstWave_VLMatrix_naive_IPW.Rda")
}



##############################################################################################
####Revise Person-day CD4 dataset
####Use IPW to replace missing values
####Want to create datasets for entire dataset and naive
####Do seperately for each site and them combine
####This helps us sync up with the original dataset and generate site-specific figures
####For logistic model to predict complete data, want to use all available data -- however, certain sites missing certain variables
####Need to account for these conditions.  I did it quick/dirty with for loops, but not most efficient
##############################################################################################


CD4.IPW.bysite<-function(s,naiveonly="no"){
set.seed(455)
inclusion<-CCASAnet_Analysis$site==s
if (naiveonly=="yes") inclusion<-CCASAnet_Analysis$site==s & CCASAnet_Analysis$naive==1
CCASAnet_Analysis_site<-CCASAnet_Analysis[inclusion,]
CCASAnet_Analysis_site$modetransmission<-as.character(CCASAnet_Analysis_site$modetransmission)
CCASAnet_Analysis_site$ARVclass<-as.character(CCASAnet_Analysis_site$ARVclass)

cd4.matrix.90.site<-cd4.matrix.90[inclusion,]
cd4.matrix.cat.90.site<-cd4.matrix.cat.90[inclusion,]
cd4.matrix.cat.90.IPW<-cd4.matrix.90.IPW<-matrix(NA,nrow(cd4.matrix.90.site),ncol(cd4.matrix.90.site))

for (pp in 1:ncol(cd4.matrix.90)){
complete<-ifelse(cd4.matrix.cat.90.site[,pp]=="Missing",0,
		  ifelse(cd4.matrix.cat.90.site[,pp] %in% c("Dead","LTFU"),NA,1))


#Model probably isn't very reliable when number of obs is less than 5...probably best just to assign equal weights
if (sum(is.na(complete)==F)<=5){
	p<-rep(1,sum(is.na(complete)==F))
}
if (sum(is.na(complete)==F)>5){
	if (s=="haiti") {
	#Haiti does not have any mode of transmission data
		if (naiveonly=="no") { output<-glm(complete~age+male+aids.initiation.plus+ARVclass+factor(naive),data=CCASAnet_Analysis_site,family="binomial")}
		if (naiveonly=="yes") { output<-glm(complete~age+male+aids.initiation.plus+ARVclass,data=CCASAnet_Analysis_site,family="binomial")}
	}
	if (s!="haiti") {
        #Mexico has very few non-naive patients.  Original code included 'naive' as a covariate for all sites.   I am amending it here to not be included for Mexico (06JUL2016)
		if (naiveonly=="no" & s!="mexico") {output<-glm(complete~age+ male+aids.initiation.plus+ARVclass+modetransmission+factor(naive),data=CCASAnet_Analysis_site,family="binomial")}
		if (naiveonly=="yes" | s=="mexico") {output<-glm(complete~male+aids.initiation.plus+ARVclass+modetransmission,data=CCASAnet_Analysis_site,family="binomial")}
	}
	p<-as.numeric(1/(1+exp(-predict(output,newdata=CCASAnet_Analysis_site[is.na(complete)==F & complete==1,]))))
}
weight.mat.pre<-data.frame(as.numeric(cd4.matrix.90.site[is.na(complete)==F & complete==1,pp]),1/p)
colnames(weight.mat.pre)<-c("cd4","inv.p")
weight.mat<-weight.mat.pre[order(weight.mat.pre[,"cd4"]),]

temp<-NULL
if (nrow(weight.mat)>0){
for (k in 1:nrow(weight.mat)){
	#IPW is a little trickier when trying to find quantiles
	#Here, I increase each weight by a factor of 100, round it, and create replicates for each CD4 according to that increased weight
	#Then, we later shrink the dataset back down to size using quantiles!
	temp<-c(temp,rep(weight.mat$cd4[k],round(100*weight.mat$inv.p[k])))
}
}
cd4.matrix.90.IPW[,pp]<-c(temp[round(1:sum(is.na(complete)==F)/sum(is.na(complete)==F)*length(temp))],rep("Dead",sum(cd4.matrix.cat.90.site[,pp]=="Dead")),rep(NA,sum(cd4.matrix.cat.90.site[,pp] %in%  c("LTFU"))))
#cd4.matrix.cat.90.IPW[,pp]<-c(temp[round(1:sum(is.na(complete)==F)/sum(is.na(complete)==F)*length(temp))],rep("Dead",sum(cd4.matrix.cat.90.site[,pp]=="Dead")),rep("LTFU",sum(cd4.matrix.cat.90.site[,pp] %in%  c("LTFU"))))
#print(pp)
}
return(cd4.matrix.90.IPW)

}

if (update==1){
    cd4.matrix.90.IPW.argentina<-CD4.IPW.bysite("argentina")
    cd4.matrix.90.IPW.brazil<-CD4.IPW.bysite("brazil")
    cd4.matrix.90.IPW.chile<-CD4.IPW.bysite("chile")
    cd4.matrix.90.IPW.haiti<-CD4.IPW.bysite("haiti")
    cd4.matrix.90.IPW.honduras<-CD4.IPW.bysite("honduras")
    cd4.matrix.90.IPW.mexico<-CD4.IPW.bysite("mexico")
    cd4.matrix.90.IPW<-rbind(cd4.matrix.90.IPW.argentina,cd4.matrix.90.IPW.brazil,cd4.matrix.90.IPW.chile,cd4.matrix.90.IPW.haiti,cd4.matrix.90.IPW.honduras,cd4.matrix.90.IPW.mexico)
    #save(cd4.matrix.90.IPW,file="/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_CD4Matrix_IPW.Rda")
    save(cd4.matrix.90.IPW,file="FirstWave_CD4Matrix_IPW.Rda")




    cd4.matrix.naive.IPW.argentina<-CD4.IPW.bysite("argentina",naiveonly="yes")
    cd4.matrix.naive.IPW.brazil<-CD4.IPW.bysite("brazil",naiveonly="yes")
    cd4.matrix.naive.IPW.chile<-CD4.IPW.bysite("chile",naiveonly="yes")
    cd4.matrix.naive.IPW.haiti<-CD4.IPW.bysite("haiti",naiveonly="yes")
    cd4.matrix.naive.IPW.honduras<-CD4.IPW.bysite("honduras",naiveonly="yes")
    cd4.matrix.naive.IPW.mexico<-CD4.IPW.bysite("mexico",naiveonly="yes")
    cd4.matrix.naive.IPW<-rbind(cd4.matrix.naive.IPW.argentina,cd4.matrix.naive.IPW.brazil,cd4.matrix.naive.IPW.chile,cd4.matrix.naive.IPW.haiti,cd4.matrix.naive.IPW.honduras,cd4.matrix.naive.IPW.mexico)
    #save(cd4.matrix.naive.IPW,file="/Users/giganti/Documents/CCASAnet/FirstWave/Rdatasets/FirstWave_CD4Matrix_naive_IPW.Rda")

    save(cd4.matrix.naive.IPW,file="Rdatasets/FirstWave_CD4Matrix_naive_IPW.Rda")
}
##################################################################################################################


################################################################################################################
#####Now need to use this person-day data to generate figures
####Need to use different functions because we want to use the 'original' person-day datasets to calculate percentages of missing that go in bottom of table,
###but use the new datasets to actually make figure!
##################################################################################################################

#Need to use percentages from non-weighted, but values from IPW data
PlotDataTableIPW<-function(vl.matrix.cat.IPW,cd4.matrix.IPW,vl.matrix.cat,cd4.matrix.cat,tiff.file="No",EveryDay="No",RemoveMissing="Yes",window=90,legendinclude="FALSE"){
    if (tiff.file=="No"){
        numsize<-4.5  #Was actually 4 in PlotFn() in previous versions.  May want to change back to 4 for pdf version?
        textsize<-NULL
        marginsleft<-0.5
        marginright<-0
        
    }
    
    if (tiff.file=="Yes"){
        #Plots look differently when saved as pdf v tiff
        #Notably, the size of the the numbers (numsize), axes text (textsize), points (pointsize),and spacing of margins (marginsleft/marginright) differ
        #The following code should allow plots to look reasonable for each type...just specify the variable "tiff.file" in the function statement
        numsize<-1.5
        textsize<-4
        marginsleft<-0.5
        marginright<--0.5
        
    }
    options("OutDec"=".")
    
    require(ggplot2)
    require(grid)
    require(reshape2)
    
    
    p1<-PlotFn(vl.matrix.cat.IPW,cd4.matrix.IPW,tiff.file=tiff.file,EveryDay=EveryDay,RemoveMissing=RemoveMissing,window=window,legendinclude=legendinclude)
    
    
    #18AUG2014 - regardless of windows, only print VL percentages every year
    if (window==90 | window==180) {
        timepoints<-c(1,floor(seq(1:10)*365.25))
        timepoints.plot<-c(30,floor(seq(1:10)*365.25)-50)
    }
    
    
    vl.freqbytime<-LabPercentFn(vl.matrix.cat,timepoints,timepoints.plot)
    cd4.freqbytime<-LabPercentFn(cd4.matrix.cat,timepoints,timepoints.plot)
    
    
    none <- element_blank()
    data_table <- ggplot(vl.freqbytime, aes(x = timepoints, y = 1,
    label = format(V1, nsmall = 1), colour = 1)) +
    geom_text(size = numsize) +
    scale_y_discrete(labels = "VL")+ theme_bw()  +
    theme(panel.grid.major = none, legend.position = "none",
    panel.border = none, axis.text.x = none,
    axis.ticks = none) + theme(plot.margin = unit(c(-0.5, marginright, 0, marginsleft), "lines")) + xlab(NULL) + ylab(NULL) +theme(text = element_text(size=textsize))
    
    
    none <- element_blank()
    data_table2 <- ggplot(cd4.freqbytime, aes(x = timepoints, y = 1,
    label = format(V1, nsmall = 1), colour = 1)) +
    geom_text(size = numsize) +
    scale_y_discrete(labels = "CD4")+ theme_bw()  +
    theme(panel.grid.major = none, legend.position = "none",
    panel.border = none, axis.text.x = none,
    axis.ticks = none) + theme(plot.margin = unit(c(-0.5, marginright, 0, 0), "lines")) + xlab(NULL) + ylab(NULL) +theme(text = element_text(size=textsize))
    
    #Ineffecient (but quick!) strategy to add a line of text to plot
    none <- element_blank()
    data_table3 <- ggplot(vl.freqbytime, aes(x = timepoints, y = 1,
    label = format("", nsmall = 1), colour = 1)) +
    geom_text(size = numsize) +
    scale_y_discrete(labels = "% measured")+ theme_bw()  +
    theme(panel.grid.major = none, legend.position = "none",
    panel.border = none, axis.text.x = none,
    axis.ticks = none) + theme(plot.margin = unit(c(-0.5, marginright, 0, 0), "lines")) + xlab(NULL) + ylab(NULL) +theme(text = element_text(size=textsize))
    
    
    
    if (tiff.file=="Yes") {
        Layout <- grid.layout(nrow = 4, ncol = 1, heights = unit(c(2,
        0.06,0.075,0.075), c("null", "null")))
    }
    
    if (tiff.file=="No") {
        Layout <- grid.layout(nrow = 4, ncol = 1, heights = unit(c(2,
        0.1,0.05,0.05), c("null", "null")))
    }
    #grid.show.layout(Layout)
    vplayout <- function(...) {
        grid.newpage()
        pushViewport(viewport(layout = Layout))
    }
    
    subplot <- function(x, y) viewport(layout.pos.row = x,
    layout.pos.col = y)
    
    mmplot <- function(a, b,c,d) {
        vplayout()
        print(a, vp = subplot(1, 1))
        print(b, vp = subplot(2, 1))
        print(c, vp = subplot(3, 1))
        print(d, vp = subplot(4, 1))
    }
    
    mmplot(p1, data_table3,data_table,data_table2)
}



PlotDataTableSiteIPW<-function(sitelab,vl.matrix.cat.IPW,cd4.matrix.IPW,vl.matrix.cat,cd4.matrix.cat,tiff.file=tiff.file,EveryDay="Yes",RemoveMissing="No",window=90,legendinclude="FALSE",Cohort){
    
    vl.matrix.cat.IPW<-vl.matrix.cat[Cohort$site==sitelab,]
    cd4.matrix.IPW<-cd4.matrix.IPW[Cohort$site==sitelab,]
    vl.matrix.cat<-vl.matrix.cat[Cohort$site==sitelab,]
    cd4.matrix.cat<-cd4.matrix.cat[Cohort$site==sitelab,]
    PlotDataTableIPW(vl.matrix.cat.IPW,cd4.matrix.IPW,vl.matrix.cat,cd4.matrix.cat, tiff.file=tiff.file, EveryDay=EveryDay,RemoveMissing=RemoveMissing, window=window, legendinclude=legendinclude)
}

##################################################################################################################




################################################################################################################
###All code is written.  Now we just need to create figures!!!!
##################################################################################################################


#################################################################################################################
#Entire cohort
#Will grab original and IPW person-day datasets!

#setwd("~/Documents/CCASAnet/FirstWave")
#source('~/Documents/CCASAnet/FirstWave/FirstWaveAnalysisFunctions.R', chdir = TRUE)
#load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_VLMatrix.Rda")
#load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_CD4Matrix.Rda")

#load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_CD4Matrix_IPW.Rda")
#load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_VLMatrix_IPW.Rda")


setwd("~/Dropbox/datasim/first-wave")
source('FirstWaveAnalysisFunctions.R', chdir = TRUE)
load("FirstWave_VLMatrix.Rda")
load("FirstWave_CD4Matrix.Rda")

load("FirstWave_CD4Matrix_IPW.Rda")
load("FirstWave_VLMatrix_IPW.Rda")


#Provide categories for CD4 counts - needed to count percent missing
#Need to manually re-assign the LTFU
cd4.matrix.cat.90<-GenerateCD4catmatrix(cd4.matrix.90,Cohort=Pre2004Cohort)



#Need to create a few new folders (2016-04-02)
if (dir.exists("Figures")==FALSE)    dir.create("Figures")
if (dir.exists("Figures/IPW")==FALSE)    dir.create("Figures/IPW")
if (dir.exists("Figures/IPW/TIFF")==FALSE)    dir.create("Figures/IPW/TIFF")



pdf("Figures/FirstWave_VLLegend.pdf")

label.vl2<-c("0-400","401-1000","> 1000","LTFU","Dead")

par(mfrow=c(1,1),mar=c(0,0,0,0))
x<-rnorm(1)
y<-rnorm(1)
plot(x~y,col=0,xlim=c(0,1),ylim=c(0,1),axes=F,xlab="",ylab="")
legend(0.05,0.9,label.vl2,fill=c("green", "orange", "red","grey90","black"),title="",bty="n",horiz=F,ncol=6,cex=0.8,x.intersp=3)
dev.off()



#Create tiffs for Figures 1/2
tiff("Figures/IPW/TIFF/FirstWave_VL_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableIPW(vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",window=90,legendinclude="TRUE")
dev.off()
tiff("Figures/IPW/TIFF/FirstWave_VL_argentina_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("argentina",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",Cohort=Pre2004Cohort)
dev.off()
tiff("Figures/IPW/TIFF/FirstWave_VL_brazil_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("brazil",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",Cohort=Pre2004Cohort)
dev.off()
tiff("Figures/IPW/TIFF/FirstWave_VL_chile_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("chile",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",Cohort=Pre2004Cohort)
dev.off()
tiff("Figures/IPW/TIFF/FirstWave_VL_honduras_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("honduras",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",Cohort=Pre2004Cohort)
dev.off()
tiff("Figures/IPW/TIFF/FirstWave_VL_mexico_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("mexico",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",Cohort=Pre2004Cohort)
dev.off()
tiff("Figures/IPW/TIFF/FirstWave_VL_haiti_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("haiti",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="Yes",EveryDay="No",RemoveMissing="No",Cohort=Pre2004Cohort)
dev.off()








#Create alternative PDF versions
pdf("Figures/IPW/FirstWave_VL_IPW.pdf")
PlotDataTableIPW(vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="No",EveryDay="No",RemoveMissing="Yes",window=90,legendinclude="TRUE")
dev.off()
pdf("Figures/IPW/FirstWave_VL_argentina_IPW.pdf")
PlotDataTableSiteIPW("argentina",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="No",EveryDay="No",RemoveMissing="Yes",Cohort=Pre2004Cohort)
dev.off()
pdf("Figures/IPW/FirstWave_VL_brazil_IPW.pdf")
PlotDataTableSiteIPW("brazil",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="No",EveryDay="No",RemoveMissing="Yes",Cohort=Pre2004Cohort)
dev.off()
pdf("Figures/IPW/FirstWave_VL_chile_IPW.pdf")
PlotDataTableSiteIPW("chile",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="No",EveryDay="No",RemoveMissing="Yes",Cohort=Pre2004Cohort)
dev.off()
pdf("Figures/IPW/FirstWave_VL_honduras_IPW.pdf")
PlotDataTableSiteIPW("honduras",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="No",EveryDay="No",RemoveMissing="Yes",Cohort=Pre2004Cohort)
dev.off()
pdf("Figures/IPW/FirstWave_VL_mexico_IPW.pdf")
PlotDataTableSiteIPW("mexico",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="No",EveryDay="No",RemoveMissing="Yes",Cohort=Pre2004Cohort)
dev.off()
pdf("Figures/IPW/FirstWave_VL_haiti_IPW.pdf")
PlotDataTableSiteIPW("haiti",vl.matrix.cat.90.IPW,cd4.matrix.90.IPW,vl.matrix.cat.90,cd4.matrix.cat.90,tiff.file="No",EveryDay="No",RemoveMissing="No",Cohort=Pre2004Cohort)
dev.off()





##################################################################################################################
###Naive-only cohort
##################################################################################################################



NaivePre2004Cohort<-Pre2004Cohort[CCASAnet_Analysis$recart_y==0,]

#load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_VLMatrix.Rda")
load("FirstWave_VLMatrix.Rda")
vl.matrix.cat.naive<-vl.matrix.cat.90[CCASAnet_Analysis$recart_y==0,]
rm(vl.matrix.cat.90)

#load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_CD4Matrix.Rda")
load("FirstWave_CD4Matrix.Rda")
cd4.matrix.naive<-cd4.matrix.90[CCASAnet_Analysis$recart_y==0,]
cd4.matrix.cat.naive<-GenerateCD4catmatrix(cd4.matrix.naive,Cohort=NaivePre2004Cohort)



#load("/Users/giganti/Documents/CCASAnet/FirstWave/Rdatasets/FirstWave_VLMatrix_naive_IPW.Rda")
#load("/Users/giganti/Documents/CCASAnet/FirstWave/Rdatasets/FirstWave_CD4Matrix_naive_IPW.Rda")
load("Rdatasets/FirstWave_VLMatrix_naive_IPW.Rda")
load("Rdatasets/FirstWave_CD4Matrix_naive_IPW.Rda")



tiff("Figures/IPW/TIFF/FirstWave_VL_naive_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableIPW(vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",window=90,legendinclude="TRUE")
dev.off()

tiff("Figures/IPW/TIFF/FirstWave_VL_argentina_naive_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("argentina",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",Cohort=NaivePre2004Cohort)
dev.off()
tiff("Figures/IPW/TIFF/FirstWave_VL_brazil_naive_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("brazil",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",Cohort=NaivePre2004Cohort)
dev.off()
tiff("Figures/IPW/TIFF/FirstWave_VL_chile_naive_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("chile",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",Cohort=NaivePre2004Cohort)
dev.off()

tiff("Figures/IPW/TIFF/FirstWave_VL_honduras_naive_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("honduras",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",Cohort=NaivePre2004Cohort)
dev.off()
tiff("Figures/IPW/TIFF/FirstWave_VL_mexico_naive_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("mexico",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="Yes",EveryDay="No",RemoveMissing="Yes",Cohort=NaivePre2004Cohort)
dev.off()

tiff("Figures/IPW/TIFF/FirstWave_VL_haiti_naive_IPW.tiff",width = 3, height = 3, units = "in", pointsize = 5, res = 300, compression = 'lzw')
PlotDataTableSiteIPW("haiti",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="Yes",EveryDay="No",RemoveMissing="No",Cohort=NaivePre2004Cohort)
dev.off()





pdf("Figures/IPW/FirstWave_VL_naive_IPW.pdf")
PlotDataTableIPW(vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="No",EveryDay="No",RemoveMissing="Yes",window=90,legendinclude="FALSE")
dev.off()

pdf("Figures/IPW/FirstWave_VL_argentina_naive_IPW.pdf")
PlotDataTableSiteIPW("argentina",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="No",EveryDay="No",RemoveMissing="Yes",Cohort=NaivePre2004Cohort)
dev.off()
pdf("Figures/IPW/FirstWave_VL_brazil_naive_IPW.pdf")
PlotDataTableSiteIPW("brazil",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="No",EveryDay="No",RemoveMissing="Yes",Cohort=NaivePre2004Cohort)
dev.off()
pdf("Figures/IPW/FirstWave_VL_chile_naive_IPW.pdf")
PlotDataTableSiteIPW("chile",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="No",EveryDay="No",RemoveMissing="Yes",Cohort=NaivePre2004Cohort)
dev.off()

pdf("Figures/IPW/FirstWave_VL_honduras_naive_IPW.pdf")
PlotDataTableSiteIPW("honduras",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="No",EveryDay="No",RemoveMissing="Yes",Cohort=NaivePre2004Cohort)
dev.off()
pdf("Figures/IPW/FirstWave_VL_mexico_naive_IPW.pdf")
PlotDataTableSiteIPW("mexico",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="No",EveryDay="No",RemoveMissing="Yes",Cohort=NaivePre2004Cohort)
dev.off()

pdf("Figures/IPW/FirstWave_VL_haiti_naive_IPW.pdf")
PlotDataTableSiteIPW("haiti",vl.matrix.cat.naive.IPW,cd4.matrix.naive.IPW,vl.matrix.cat.naive,cd4.matrix.cat.naive,tiff.file="No",EveryDay="No",RemoveMissing="No",Cohort=NaivePre2004Cohort)
dev.off()









##################################################################################################################
###Non-naive-only cohort
#08DEC2015
##################################################################################################################

NonnaivePre2004Cohort<-Pre2004Cohort[CCASAnet_Analysis$recart_y!=0,]

#First get traditional non-naive datasets for CD4/VL
#load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_VLMatrix.Rda")
load("FirstWave_VLMatrix.Rda")
vl.matrix.cat.nonnaive<-vl.matrix.cat.90[CCASAnet_Analysis$recart_y!=0,]
rm(vl.matrix.cat.90)

#load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_CD4Matrix.Rda")
load("FirstWave_CD4Matrix.Rda")
cd4.matrix.nonnaive<-cd4.matrix.90[CCASAnet_Analysis$recart_y!=0,]
cd4.matrix.cat.nonnaive<-GenerateCD4catmatrix(cd4.matrix.nonnaive,Cohort=NonnaivePre2004Cohort)



#load("/Users/giganti/Documents/CCASAnet/FirstWave/Rdatasets/FirstWave_VLMatrix_naive_IPW.Rda")
#load("/Users/giganti/Documents/CCASAnet/FirstWave/Rdatasets/FirstWave_CD4Matrix_naive_IPW.Rda")
load("Rdatasets/FirstWave_VLMatrix_naive_IPW.Rda")
load("Rdatasets/FirstWave_CD4Matrix_naive_IPW.Rda")
#Need to get VL/CD4 labs for non-naive patients using IPW strategy
#Because of small sample sizes in certain sites, we 'backdoor' this by taking difference between full and naive datasets
#The following code should accomplish that


#vl.matrix.cat.90.IPW
#load("/Users/giganti/Documents/CCASAnet/FirstWave/FirstWave_VLMatrix_IPW.Rda")
load("FirstWave_VLMatrix_IPW.Rda")

#Crude approach -- results get wonky near end of follow-up.  However, since we are only interested in 10 years, we can truncate it before it gets to that point!
n.nonnaive<-dim(NonnaivePre2004Cohort)[1]
vl.matrix.cat.nonnaive.IPW<-matrix(NA,n.nonnaive,4000)
for (nn in 1:3700){
    #temp.nonnaive<-table(vl.matrix.cat.90.IPW[,nn]) -table(vl.matrix.cat.naive.IPW[,nn])
    
    #May have slight bug in original code -- following two lines resolves issue (04APR2016)
    T.names<-c("000-400","1001-Inf","401-1000", "Dead","LTFU","Missing")
    temp.nonnaive<-table(factor(vl.matrix.cat.90.IPW[,nn],levels=T.names)) -table(factor(vl.matrix.cat.naive.IPW[,nn],levels=T.names))

vl.matrix.cat.nonnaive.IPW[,nn]<-rep(names(temp.nonnaive),temp.nonnaive)
}

if (update==1){
    #save(vl.matrix.cat.nonnaive.IPW,file="/Users/giganti/Documents/CCASAnet/FirstWave/Rdatasets/FirstWave_VLMatrix_nonnaive_IPW.Rda")
    save(vl.matrix.cat.nonnaive.IPW,file="Rdatasets/FirstWave_VLMatrix_nonnaive_IPW.Rda")
}




GetCD4s<-function(cd4mat,timez){
    a<-cd4mat[,floor(365.25*timez)]
    b<-a[a!="Dead"]
    c<-as.numeric(b)
    return(c)
}


#function to get labs for non-naive by removing naive labs from the entire cohort
#Cannot do IPW for just non-naive due to small sample sizes at some sites
genNonNaiveCD4<-function(cd4mat=cd4.matrix.90.IPW,cd4mat.naive=cd4.matrix.naive.IPW,timez){
    set.seed(455)
    all<-as.numeric(GetCD4s(cd4mat,timez))
    #Want to sample to mix em up!
    all.removeNA<-sample(all[is.na(all)==F])
    
    naive<-as.numeric(GetCD4s(cd4mat.naive,timez))
    naive.removeNA<-naive[is.na(naive)==F]
    
    for (g in 1:length(naive.removeNA)){
        all.removeNA<-all.removeNA[-order(abs(all.removeNA-naive.removeNA[g]))[1]]
        
    }
    return(all.removeNA)
}

if (update==1){
    cd4.matrix.nonnaive.IPW<-matrix(NA,n.nonnaive,4000)
    for (cnn in 1:3700){
        temp.cd4<-genNonNaiveCD4(timez=cnn/365)
        cd4.matrix.nonnaive.IPW[1:length(temp.cd4),cnn]<-temp.cd4
        if (length(temp.cd4) < dim(cd4.matrix.nonnaive.IPW)[1]) cd4.matrix.nonnaive.IPW[(length(temp.cd4)+1):dim(cd4.matrix.nonnaive.IPW)[1],cnn]<-"Dead"
        #print(cnn)
    }
    #save(cd4.matrix.nonnaive.IPW,file="/Users/giganti/Documents/CCASAnet/FirstWave/Rdatasets/FirstWave_CD4Matrix_nonnaive_IPW.Rda")
    save(cd4.matrix.nonnaive.IPW,file="Rdatasets/FirstWave_CD4Matrix_nonnaive_IPW.Rda")
    
    
}


#load("/Users/giganti/Documents/CCASAnet/FirstWave/Rdatasets/FirstWave_VLMatrix_nonnaive_IPW.Rda")
#load("/Users/giganti/Documents/CCASAnet/FirstWave/Rdatasets/FirstWave_CD4Matrix_nonnaive_IPW.Rda")
load("Rdatasets/FirstWave_VLMatrix_nonnaive_IPW.Rda")
load("Rdatasets/FirstWave_CD4Matrix_nonnaive_IPW.Rda")




pdf("Figures/IPW/FirstWave_VL_nonnaive_IPW.pdf")
PlotDataTableIPW(vl.matrix.cat.nonnaive.IPW,cd4.matrix.nonnaive.IPW,vl.matrix.cat.nonnaive,cd4.matrix.cat.nonnaive,tiff.file="No",EveryDay="No",RemoveMissing="Yes",window=90,legendinclude="FALSE")
dev.off()





